<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('marketing');

// 记录访问日志
record_log('访问推荐返利管理页面');

// 处理操作
$message = '';
$error = '';
$action = isset($_GET['action']) ? $_GET['action'] : '';

// 处理保存设置
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_settings'])) {
    try {
        // 验证输入
        $points = isset($_POST['points']) ? intval($_POST['points']) : 0;
        $rebate_percentage = isset($_POST['rebate_percentage']) ? floatval($_POST['rebate_percentage']) : 0;

        if ($points < 0) {
            $error = '奖励积分不能小于0';
        } elseif ($rebate_percentage < 0 || $rebate_percentage > 50) {
            $error = '返利比例必须在0%到50%之间';
        } else {
            // 检查是否已存在推荐返利活动
            $stmt = $pdo->prepare("SELECT id FROM marketing_campaigns WHERE type = 7 LIMIT 1");
            $stmt->execute();
            $campaign = $stmt->fetch();

            $pdo->beginTransaction();

            if ($campaign) {
                // 更新现有活动
                $stmt = $pdo->prepare("
                    UPDATE marketing_campaigns
                    SET description = :description,
                        discount_type = 2,
                        discount_value = :discount_value,
                        min_amount = :min_amount,
                        status = 1
                    WHERE id = :id
                ");
                $stmt->execute([
                    ':description' => "推荐新会员奖励{$points}积分，消费返利{$rebate_percentage}%",
                    ':discount_value' => $rebate_percentage,
                    ':min_amount' => $points,
                    ':id' => $campaign['id']
                ]);
                $message = '推荐返利设置已更新';
            } else {
                // 创建新活动
                $stmt = $pdo->prepare("
                    INSERT INTO marketing_campaigns (
                        name, type, description, discount_type, discount_value, min_amount,
                        start_time, end_time, status, create_time
                    ) VALUES (
                        '推荐返利活动', 7, :description, 2, :discount_value, :min_amount,
                        NOW(), DATE_ADD(NOW(), INTERVAL 10 YEAR), 1, NOW()
                    )
                ");
                $stmt->execute([
                    ':description' => "推荐新会员奖励{$points}积分，消费返利{$rebate_percentage}%",
                    ':discount_value' => $rebate_percentage,
                    ':min_amount' => $points
                ]);
                $message = '推荐返利设置已创建';
            }

            $pdo->commit();
        }
    } catch (Exception $e) {
        $pdo->rollBack();
        $error = '保存设置失败: ' . $e->getMessage();
    }
}

// 获取当前推荐返利设置
$stmt = $pdo->prepare("
    SELECT * FROM marketing_campaigns 
    WHERE type = 7 
    ORDER BY id DESC LIMIT 1
");
$stmt->execute();
$campaign = $stmt->fetch();

// 提取设置
$settings = [
    'points' => 0,
    'rebate_percentage' => 20,
];

if ($campaign) {
    // 使用min_amount存储推荐积分，discount_value存储返利比例
    $settings['points'] = intval($campaign['min_amount']);
    $settings['rebate_percentage'] = floatval($campaign['discount_value']);
}

// 获取推荐统计
$stmt = $pdo->query("
    SELECT COUNT(*) as count
    FROM member_points_log 
    WHERE source = '推荐'
");
$total_referrals = $stmt->fetch()['count'];

$stmt = $pdo->query("
    SELECT SUM(points) as total
    FROM member_points_log 
    WHERE source = '推荐'
");
$total_points = $stmt->fetch()['total'] ?: 0;

$stmt = $pdo->query("
    SELECT COALESCE(SUM(points), 0) as total
    FROM member_points_log
    WHERE source = '返利'
");
$total_rebates = $stmt->fetch()['total'] ?: 0;

// 获取最佳推荐人
$stmt = $pdo->query("
    SELECT m.id, m.name, COUNT(mpl.id) as referral_count
    FROM members m
    JOIN member_points_log mpl ON m.id = mpl.member_id
    WHERE mpl.source = '推荐'
    GROUP BY m.id
    ORDER BY referral_count DESC
    LIMIT 5
");
$top_referrers = $stmt->fetchAll();

// 获取最近推荐
$stmt = $pdo->query("
    SELECT m.id as member_id, m.name as member_name, 
           mpl.points, mpl.remark, mpl.create_time
    FROM member_points_log mpl
    JOIN members m ON mpl.member_id = m.id
    WHERE mpl.source = '推荐'
    ORDER BY mpl.create_time DESC
    LIMIT 10
");
$recent_referrals = $stmt->fetchAll();

// 获取最近返利记录
$stmt = $pdo->query("
    SELECT mpl.id, m.name as member_name, mpl.points, 
           mpl.create_time, mpl.remark
    FROM member_points_log mpl
    JOIN members m ON mpl.member_id = m.id
    WHERE mpl.source = '返利'
    ORDER BY mpl.create_time DESC
    LIMIT 10
");
$recent_rebates = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>推荐返利管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>推荐返利管理</h2>
            <div class="breadcrumb">
                <a href="index.php">营销推广</a> &gt;
                <span>推荐返利管理</span>
            </div>
        </div>

        <div class="content">
            <?php if ($message): ?>
                <div class="alert alert-success"><?php echo $message; ?></div>
            <?php endif; ?>

            <?php if ($error): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 返利配置 -->
            <div class="section-panel">
                <div class="section-header">
                    <h3>返利配置</h3>
                </div>
                <div class="section-body">
                    <form action="" method="post" class="form">
                        <div class="form-group">
                            <label for="points">推荐新会员奖励积分：</label>
                            <input type="number" id="points" name="points" value="<?php echo $settings['points']; ?>" min="0" class="form-control" required>
                            <div class="form-help">推荐者获得的积分奖励（每推荐一位新会员）</div>
                        </div>

                        <div class="form-group">
                            <label for="rebate_percentage">被推荐者消费返利比例：</label>
                            <div class="input-group">
                                <input type="number" id="rebate_percentage" name="rebate_percentage" value="<?php echo $settings['rebate_percentage']; ?>" min="0" max="50" step="0.1" class="form-control" required>
                                <div class="input-group-append">%</div>
                            </div>
                            <div class="form-help">被推荐会员消费时，推荐者获得的返利比例（限制范围：0%-50%）</div>
                        </div>

                        <div class="form-actions">
                            <button type="submit" name="save_settings" class="btn btn-primary">保存设置</button>
                        </div>
                    </form>
                </div>
            </div>

            <!-- 推荐统计 -->
            <div class="section-panel">
                <div class="section-header">
                    <h3>推荐统计</h3>
                </div>
                <div class="overview-stats">
                    <div class="stat-item">
                        <div class="stat-value"><?php echo $total_referrals; ?></div>
                        <div class="stat-label">推荐总数</div>
                    </div>
                    <div class="stat-item">
                        <div class="stat-value"><?php echo $total_points; ?></div>
                        <div class="stat-label">推荐积分奖励</div>
                    </div>
                    <div class="stat-item">
                        <div class="stat-value"><?php echo number_format($total_rebates / 100, 2); ?></div>
                        <div class="stat-label">返利总额（元）</div>
                    </div>
                </div>
            </div>

            <!-- 最佳推荐人 -->
            <div class="section-panel">
                <div class="section-header">
                    <h3>最佳推荐人</h3>
                </div>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>会员ID</th>
                                <th>会员姓名</th>
                                <th>推荐人数</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($top_referrers)): ?>
                                <?php foreach ($top_referrers as $referrer): ?>
                                    <tr>
                                        <td><?php echo $referrer['id']; ?></td>
                                        <td><?php echo htmlspecialchars($referrer['name']); ?></td>
                                        <td><?php echo $referrer['referral_count']; ?></td>
                                        <td>
                                            <a href="../member/detail.php?id=<?php echo $referrer['id']; ?>" class="btn btn-sm btn-secondary">查看详情</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="4" class="text-center">暂无数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <!-- 最近推荐 -->
            <div class="section-panel">
                <div class="section-header">
                    <h3>最近推荐</h3>
                </div>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>会员ID</th>
                                <th>会员姓名</th>
                                <th>奖励积分</th>
                                <th>备注说明</th>
                                <th>推荐时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($recent_referrals)): ?>
                                <?php foreach ($recent_referrals as $referral): ?>
                                    <tr>
                                        <td><?php echo $referral['member_id']; ?></td>
                                        <td><?php echo htmlspecialchars($referral['member_name']); ?></td>
                                        <td><?php echo $referral['points']; ?></td>
                                        <td><?php echo htmlspecialchars($referral['remark']); ?></td>
                                        <td><?php echo substr($referral['create_time'], 0, 16); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <!-- 最近返利记录 -->
            <div class="section-panel">
                <div class="section-header">
                    <h3>最近返利记录</h3>
                </div>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>记录ID</th>
                                <th>推荐人</th>
                                <th>奖励积分</th>
                                <th>返利金额（元）</th>
                                <th>时间</th>
                                <th>备注</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($recent_rebates)): ?>
                                <?php foreach ($recent_rebates as $rebate): ?>
                                    <tr>
                                        <td><?php echo $rebate['id']; ?></td>
                                        <td><?php echo htmlspecialchars($rebate['member_name']); ?></td>
                                        <td><?php echo $rebate['points']; ?></td>
                                        <td><?php echo number_format($rebate['points'] / 100, 2); ?></td>
                                        <td><?php echo substr($rebate['create_time'], 0, 16); ?></td>
                                        <td><?php echo htmlspecialchars($rebate['remark']); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</body>

</html>