<?php
// product/index.php - 商品与库存管理模块首页
session_start();
require_once '../database_config.php';

// 检查用户是否有访问权限
check_permission_or_die('product');

// 获取商品和库存相关统计数据
$stats = [];

// 获取商品总数
$stmt = $pdo->query("SELECT COUNT(*) as total FROM products");
$stats['product_count'] = $stmt->fetch()['total'];

// 获取低库存预警商品数
$stmt = $pdo->query("SELECT COUNT(*) as total FROM products WHERE stock <= warning_stock");
$stats['warning_count'] = $stmt->fetch()['total'];

// 获取供应商数量
$stmt = $pdo->query("SELECT COUNT(*) as total FROM suppliers");
$stats['supplier_count'] = $stmt->fetch()['total'];

// 获取最近7天的库存变动记录
$stmt = $pdo->query("SELECT COUNT(*) as total FROM inventory_records WHERE create_time >= DATE_SUB(NOW(), INTERVAL 7 DAY)");
$stats['recent_inventory_records'] = $stmt->fetch()['total'];

// 记录操作日志
record_log("访问商品与库存管理模块首页");
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>商品与库存管理 - <?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>商品与库存管理</h2>
        </div>

        <div class="content">
            <!-- 数据概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>商品总数</h3>
                    <div class="number"><?php echo $stats['product_count']; ?></div>
                    <div class="desc">系统内所有商品</div>
                </div>
                <div class="dashboard-card">
                    <h3>库存预警</h3>
                    <div class="number"><?php echo $stats['warning_count']; ?></div>
                    <div class="desc">低于预警阈值的商品</div>
                </div>
                <div class="dashboard-card">
                    <h3>供应商数量</h3>
                    <div class="number"><?php echo $stats['supplier_count']; ?></div>
                    <div class="desc">合作供应商</div>
                </div>
                <div class="dashboard-card">
                    <h3>近7天库存变动</h3>
                    <div class="number"><?php echo $stats['recent_inventory_records']; ?></div>
                    <div class="desc">包含采购、销售、报损等</div>
                </div>
            </div>

            <!-- 功能链接 -->
            <div class="function-links">
                <a href="list.php" class="function-link">
                    <h3>商品管理</h3>
                </a>
                <a href="inventory.php" class="function-link">
                    <h3>库存管理</h3>
                </a>
                <a href="supplier.php" class="function-link">
                    <h3>供应商管理</h3>
                </a>
            </div>

            <!-- 库存预警列表 -->
            <?php if ($stats['warning_count'] > 0): ?>
                <div class="alert alert-danger">
                    <strong>注意：</strong>有 <?php echo $stats['warning_count']; ?> 个商品库存低于预警阈值，请及时补货！
                </div>

                <h3>库存预警商品</h3>
                <div class="table-responsive">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>商品编码</th>
                                <th>商品名称</th>
                                <th>当前库存</th>
                                <th>预警阈值</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                            $stmt = $pdo->query("SELECT p.*, c.name as category_name FROM products p 
                                            LEFT JOIN product_categories c ON p.category_id = c.id 
                                            WHERE p.stock <= p.warning_stock 
                                            ORDER BY p.stock/p.warning_stock ASC 
                                            LIMIT 10");
                            while ($row = $stmt->fetch()):
                            ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($row['code']); ?></td>
                                    <td><?php echo htmlspecialchars($row['name']); ?></td>
                                    <td class="<?php echo $row['stock'] == 0 ? 'status-inactive' : ''; ?>">
                                        <?php echo $row['stock']; ?>
                                    </td>
                                    <td><?php echo $row['warning_stock']; ?></td>
                                    <td>
                                        <a href="inventory.php?action=purchase&product_id=<?php echo $row['id']; ?>" class="btn btn-sm btn-primary">采购入库</a>
                                    </td>
                                </tr>
                            <?php endwhile; ?>
                        </tbody>
                    </table>
                    <?php if ($stats['warning_count'] > 10): ?>
                        <div class="pagination-info">
                            显示前10条记录，查看全部请前往<a href="list.php?filter=warning">商品管理</a>
                        </div>
                    <?php endif; ?>
                </div>
            <?php endif; ?>

            <!-- 最近库存变动记录 -->
            <h3>最近库存变动记录</h3>
            <div class="table-responsive">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>时间</th>
                            <th>商品名称</th>
                            <th>类型</th>
                            <th>变动数量</th>
                            <th>变动后库存</th>
                            <th>操作员</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT i.*, p.name as product_name, p.code as product_code 
                                            FROM inventory_records i 
                                            LEFT JOIN products p ON i.product_id = p.id 
                                            ORDER BY i.create_time DESC 
                                            LIMIT 10");
                        while ($row = $stmt->fetch()):
                            // 设置类型文本和样式
                            $type_text = '';
                            $type_class = '';
                            switch ($row['type']) {
                                case 1:
                                    $type_text = '采购入库';
                                    $type_class = 'status-active';
                                    break;
                                case 2:
                                    $type_text = '销售出库';
                                    break;
                                case 3:
                                    $type_text = '报损';
                                    $type_class = 'status-inactive';
                                    break;
                                case 4:
                                    $type_text = '盘点调整';
                                    break;
                                default:
                                    $type_text = '未知';
                            }
                        ?>
                            <tr>
                                <td><?php echo date('Y-m-d H:i', strtotime($row['create_time'])); ?></td>
                                <td><?php echo htmlspecialchars($row['product_name'] . ' (' . $row['product_code'] . ')'); ?></td>
                                <td class="<?php echo $type_class; ?>"><?php echo $type_text; ?></td>
                                <td><?php echo $row['quantity'] > 0 ? '+' . $row['quantity'] : $row['quantity']; ?></td>
                                <td><?php echo $row['after_stock']; ?></td>
                                <td><?php echo htmlspecialchars($row['operator']); ?></td>
                            </tr>
                        <?php endwhile; ?>
                    </tbody>
                </table>
                <div class="pagination-info">
                    显示最近10条记录，查看更多请前往<a href="inventory.php">库存管理</a>
                </div>
            </div>
        </div>
    </div>
</body>

</html>