-- FloraEase系统管理相关数据库表
-- 用户管理表
CREATE TABLE IF NOT EXISTS `sys_users` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '用户ID',
    `username` varchar(50) NOT NULL COMMENT '用户名',
    `password` varchar(50) NOT NULL COMMENT '密码',
    `role_id` int(11) NOT NULL DEFAULT 2 COMMENT '角色ID',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_username` (`username`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '系统用户表';

-- 角色权限表
CREATE TABLE IF NOT EXISTS `sys_roles` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '角色ID',
    `role_name` varchar(50) NOT NULL COMMENT '角色名称',
    `permissions` text DEFAULT NULL COMMENT '权限(JSON格式)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '角色权限表';

-- 操作日志表
CREATE TABLE IF NOT EXISTS `sys_logs` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '日志ID',
    `user_id` int(11) DEFAULT NULL COMMENT '操作用户ID',
    `username` varchar(50) DEFAULT NULL COMMENT '操作用户名',
    `operation` varchar(500) NOT NULL COMMENT '操作描述',
    `ip` varchar(50) DEFAULT NULL COMMENT '操作IP',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '操作时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '操作日志表';

-- 数据备份表
CREATE TABLE IF NOT EXISTS `sys_backups` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '备份ID',
    `backup_name` varchar(100) NOT NULL COMMENT '备份名称',
    `backup_path` varchar(255) NOT NULL COMMENT '备份文件路径',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '数据备份表';

-- 初始化角色数据
INSERT INTO
    `sys_roles` (`id`, `role_name`, `permissions`)
VALUES
    (1, '系统管理员', '{"all": true, "system": true}'),
    (
        2,
        '店长',
        '{"store": true, "employee": true, "order": true, "inventory": true, "member": true}'
    ),
    (
        3,
        '店员',
        '{"order": true, "member": true, "product": true}'
    ),
    (4, '配送员', '{"delivery": true}'),
    (
        5,
        '财务人员',
        '{"finance": true, "order": {"view": true}, "report": true}'
    ),
    (
        6,
        '运营人员',
        '{"marketing": true, "member": {"view": true}, "statistics": true}'
    );

-- 添加初始管理员用户 admin/admin
INSERT INTO
    `sys_users` (`username`, `password`, `role_id`)
VALUES
    ('admin', 'admin', 1);

-- 门店管理相关数据表
-- 1. 门店表
CREATE TABLE IF NOT EXISTS `stores` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '门店ID',
    `name` varchar(100) NOT NULL COMMENT '门店名称',
    `area` varchar(50) NOT NULL COMMENT '所属区域',
    `address` varchar(255) NOT NULL COMMENT '门店地址',
    `contact_person` varchar(50) NOT NULL COMMENT '联系人',
    `phone` varchar(20) NOT NULL COMMENT '联系电话',
    `business_hours` varchar(100) NOT NULL COMMENT '营业时间',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态(0:关闭,1:营业)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '门店信息表';

-- 2. 员工表
CREATE TABLE IF NOT EXISTS `employees` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '员工ID',
    `store_id` int(11) NOT NULL COMMENT '所属门店ID',
    `name` varchar(50) NOT NULL COMMENT '员工姓名',
    `position` varchar(50) NOT NULL COMMENT '职位',
    `phone` varchar(20) NOT NULL COMMENT '联系电话',
    `entry_date` date NOT NULL COMMENT '入职日期',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态(0:离职,1:在职)',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '员工信息表';

-- 3. 门店统计表
CREATE TABLE IF NOT EXISTS `store_statistics` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '统计ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `date` date NOT NULL COMMENT '统计日期',
    `period` varchar(10) NOT NULL COMMENT '统计周期(day,week,month)',
    `sales_amount` decimal(10, 2) DEFAULT 0.00 COMMENT '销售金额',
    `order_count` int(11) DEFAULT 0 COMMENT '订单数量',
    `peak_hours` varchar(50) DEFAULT NULL COMMENT '高峰时段',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_store_date_period` (`store_id`, `date`, `period`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '门店营业统计表';

-- 插入默认数据
INSERT INTO
    `stores` (
        `name`,
        `area`,
        `address`,
        `contact_person`,
        `phone`,
        `business_hours`
    )
VALUES
    (
        '总店',
        '北京市',
        '北京市朝阳区花园路1号',
        '张经理',
        '13800138000',
        '09:00-21:00'
    );

-- 会员管理相关数据表
-- 1. 会员等级表
CREATE TABLE IF NOT EXISTS `member_levels` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '等级ID',
    `level_name` varchar(50) NOT NULL COMMENT '等级名称',
    `min_points` int(11) NOT NULL DEFAULT 0 COMMENT '所需最低积分',
    `discount` decimal(4, 2) NOT NULL DEFAULT 1.00 COMMENT '折扣率',
    `description` varchar(255) DEFAULT NULL COMMENT '等级描述',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '会员等级表';

-- 2. 会员表
CREATE TABLE IF NOT EXISTS `members` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '会员ID',
    `name` varchar(50) NOT NULL COMMENT '会员姓名',
    `phone` varchar(20) NOT NULL COMMENT '手机号码',
    `birthday` date DEFAULT NULL COMMENT '生日',
    `address` varchar(255) DEFAULT NULL COMMENT '地址',
    `preference` varchar(255) DEFAULT NULL COMMENT '购买偏好',
    `level_id` int(11) NOT NULL DEFAULT 1 COMMENT '会员等级ID',
    `points` int(11) NOT NULL DEFAULT 0 COMMENT '积分余额',
    `balance` decimal(10, 2) NOT NULL DEFAULT 0.00 COMMENT '储值余额',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '注册时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_phone` (`phone`),
    KEY `idx_level` (`level_id`),
    CONSTRAINT `fk_member_level` FOREIGN KEY (`level_id`) REFERENCES `member_levels` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '会员信息表';

-- 3. 会员积分记录表
CREATE TABLE IF NOT EXISTS `member_points_log` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `member_id` int(11) NOT NULL COMMENT '会员ID',
    `type` tinyint(1) NOT NULL COMMENT '类型(1:获取,2:消费)',
    `points` int(11) NOT NULL COMMENT '积分变动',
    `source` varchar(50) NOT NULL COMMENT '来源(购物,充值,推荐,兑换)',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '记录时间',
    PRIMARY KEY (`id`),
    KEY `idx_member` (`member_id`),
    CONSTRAINT `fk_points_member` FOREIGN KEY (`member_id`) REFERENCES `members` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '会员积分记录表';

-- 4. 会员充值记录表
CREATE TABLE IF NOT EXISTS `member_recharge_log` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '充值ID',
    `member_id` int(11) NOT NULL COMMENT '会员ID',
    `amount` decimal(10, 2) NOT NULL COMMENT '充值金额',
    `actual_amount` decimal(10, 2) NOT NULL COMMENT '实际到账金额',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '充值时间',
    PRIMARY KEY (`id`),
    KEY `idx_member` (`member_id`),
    CONSTRAINT `fk_recharge_member` FOREIGN KEY (`member_id`) REFERENCES `members` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '会员充值记录表';

-- 插入默认会员等级数据
INSERT INTO
    `member_levels` (
        `level_name`,
        `min_points`,
        `discount`,
        `description`
    )
VALUES
    ('普通会员', 0, 1.00, '普通会员基础权益'),
    ('银卡会员', 1000, 0.95, '享受95折优惠'),
    ('金卡会员', 5000, 0.90, '享受9折优惠'),
    ('钻石会员', 10000, 0.85, '享受85折优惠及生日礼遇');

-- 1. 插入会员数据（先插入会员数据，因为订单中已经引用了会员ID=1）
INSERT INTO `members` (`id`, `name`, `phone`, `birthday`, `address`, `preference`, `level_id`, `points`, `balance`, `status`) VALUES
(1, '张三', '13512345678', '1990-01-15', '北京市海淀区中关村大街1号', '喜欢红玫瑰', 3, 5680, 358.50, 1),
(2, '李四', '13612345678', '1985-03-22', '北京市朝阳区建国路88号', '偏好绿植', 2, 1280, 120.00, 1),
(3, '王五', '13712345678', '1992-06-18', '北京市西城区西长安街66号', '喜欢百合花', 1, 520, 0.00, 1),
(4, '赵六', '13812345678', '1988-11-05', '北京市东城区东长安街100号', '偏好混合花束', 4, 12800, 1500.00, 1),
(5, '钱七', '13912345678', '1995-09-30', '北京市丰台区丰台路36号', '喜欢开业花篮', 2, 1680, 200.00, 1);

-- 2. 插入员工数据（依赖于门店表）
INSERT INTO `employees` (`store_id`, `name`, `position`, `phone`, `entry_date`, `status`) VALUES
(1, '张经理', '店长', '13800138001', '2020-01-01', 1),
(1, '店员A', '资深店员', '13800138002', '2020-02-15', 1),
(1, '店员B', '店员', '13800138003', '2021-03-10', 1),
(1, '店员C', '店员', '13800138004', '2021-06-05', 1),
(1, '李配送', '配送员', '13800138005', '2020-05-20', 1),
(1, '王配送', '配送员', '13800138006', '2021-08-15', 1),
(1, '财务小李', '财务', '13800138007', '2020-03-01', 1);

-- 3. 插入门店统计数据（依赖于门店表）
INSERT INTO `store_statistics` (`store_id`, `date`, `period`, `sales_amount`, `order_count`, `peak_hours`) VALUES
(1, '2023-05-01', 'day', 585.40, 5, '14:00-17:00'),
(1, '2023-05-02', 'day', 347.20, 3, '10:00-12:00'),
(1, '2023-05-03', 'day', 394.70, 4, '15:00-18:00'),
(1, '2023-05-04', 'day', 247.80, 2, '13:00-16:00'),
(1, '2023-05-05', 'day', 130.50, 1, '11:00-13:00'),
(1, '2023-05-01', 'week', 1705.60, 15, '14:00-17:00'),
(1, '2023-05-01', 'month', 5680.20, 52, '14:00-17:00');

-- 4. 插入会员积分记录（依赖于会员表）
INSERT INTO `member_points_log` (`member_id`, `type`, `points`, `source`, `remark`) VALUES
(1, 1, 256, '购物', '购买混合花束获得积分'),
(1, 1, 188, '购物', '购买鲜花和礼品获得积分'),
(1, 1, 288, '购物', '购买开业花篮获得积分'),
(1, 1, 5000, '推荐', '推荐10位新会员奖励'),
(1, 2, 100, '兑换', '使用积分抵扣订单金额'),
(2, 1, 1280, '购物', '累计购物获得积分'),
(3, 1, 520, '购物', '累计购物获得积分'),
(4, 1, 8800, '购物', '累计购物获得积分'),
(4, 1, 4000, '推荐', '推荐8位新会员奖励'),
(5, 1, 1680, '购物', '累计购物获得积分');

-- 5. 插入会员充值记录（依赖于会员表）
INSERT INTO `member_recharge_log` (`member_id`, `amount`, `actual_amount`, `remark`) VALUES
(1, 300.00, 330.00, '充值300元送30元'),
(1, 100.00, 100.00, '普通充值'),
(2, 100.00, 110.00, '充值100元送10元'),
(4, 1000.00, 1200.00, '充值1000元送200元'),
(4, 500.00, 550.00, '充值500元送50元'),
(5, 200.00, 220.00, '充值200元送20元');

-- 商品与库存管理相关数据表（简化版）
-- 1. 商品分类表
CREATE TABLE IF NOT EXISTS `product_categories` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '分类ID',
    `name` varchar(50) NOT NULL COMMENT '分类名称',
    `description` varchar(255) DEFAULT NULL COMMENT '分类描述',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '商品分类表';

-- 2. 商品表
CREATE TABLE IF NOT EXISTS `products` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '商品ID',
    `category_id` int(11) NOT NULL COMMENT '分类ID',
    `name` varchar(100) NOT NULL COMMENT '商品名称',
    `code` varchar(50) NOT NULL COMMENT '商品编码',
    `price` decimal(10, 2) NOT NULL COMMENT '销售价格',
    `cost_price` decimal(10, 2) DEFAULT NULL COMMENT '成本价格',
    `spec` varchar(100) DEFAULT NULL COMMENT '规格',
    `description` text DEFAULT NULL COMMENT '描述',
    `stock` int(11) NOT NULL DEFAULT 0 COMMENT '当前库存',
    `warning_stock` int(11) DEFAULT 5 COMMENT '库存预警阈值',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态(0:下架,1:上架)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_code` (`code`),
    KEY `idx_category` (`category_id`),
    CONSTRAINT `fk_product_category` FOREIGN KEY (`category_id`) REFERENCES `product_categories` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '商品表';

-- 3. 供应商表
CREATE TABLE IF NOT EXISTS `suppliers` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '供应商ID',
    `name` varchar(100) NOT NULL COMMENT '供应商名称',
    `contact_person` varchar(50) NOT NULL COMMENT '联系人',
    `phone` varchar(20) NOT NULL COMMENT '联系电话',
    `address` varchar(255) DEFAULT NULL COMMENT '地址',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态(0:禁用,1:启用)',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '供应商表';

-- 4. 库存变动记录表（包含采购、销售、报损、盘点）
CREATE TABLE IF NOT EXISTS `inventory_records` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `product_id` int(11) NOT NULL COMMENT '商品ID',
    `type` tinyint(1) NOT NULL COMMENT '类型(1:采购入库,2:销售出库,3:报损,4:盘点调整)',
    `quantity` int(11) NOT NULL COMMENT '变动数量(正:增加,负:减少)',
    `before_stock` int(11) NOT NULL COMMENT '变动前库存',
    `after_stock` int(11) NOT NULL COMMENT '变动后库存',
    `price` decimal(10, 2) DEFAULT NULL COMMENT '单价(采购/销售价)',
    `supplier_id` int(11) DEFAULT NULL COMMENT '供应商ID(用于采购)',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注',
    `operator` varchar(50) NOT NULL COMMENT '操作员',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '操作时间',
    PRIMARY KEY (`id`),
    KEY `idx_product` (`product_id`),
    KEY `idx_supplier` (`supplier_id`),
    CONSTRAINT `fk_inventory_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT,
    CONSTRAINT `fk_inventory_supplier` FOREIGN KEY (`supplier_id`) REFERENCES `suppliers` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '库存变动记录表';

-- 插入默认商品分类
INSERT INTO
    `product_categories` (`name`, `description`)
VALUES
    ('鲜花', '各类鲜切花和花束'),
    ('绿植', '室内外观赏植物'),
    ('花篮', '庆典、开业花篮'),
    ('礼品', '陪衬礼品和精美包装');

-- 插入供应商数据
INSERT INTO `suppliers` (`name`, `contact_person`, `phone`, `address`, `status`) VALUES
('北京花卉批发市场', '王经理', '13812345678', '北京市朝阳区花卉市场A区12号', 1),
('绿色园艺有限公司', '李园长', '13923456789', '上海市浦东新区园艺路88号', 1),
('花艺用品批发中心', '张总', '13534567890', '广州市天河区花艺大道23号', 1),
('进口花卉贸易公司', '刘经理', '13645678901', '深圳市福田区国贸大厦15楼', 1);

-- 插入商品数据
INSERT INTO `products` (`category_id`, `name`, `code`, `price`, `cost_price`, `spec`, `description`, `stock`, `warning_stock`, `status`) VALUES
-- 鲜花类
(1, '红玫瑰', 'F001', 9.90, 5.50, '单支', '经典红玫瑰，爱情的象征', 100, 20, 1),
(1, '向日葵', 'F002', 15.80, 8.50, '单支', '阳光向日葵，传递正能量', 50, 10, 1),
(1, '郁金香', 'F003', 12.50, 7.00, '单支', '优雅郁金香，荷兰进口', 80, 15, 1),
(1, '百合花', 'F004', 18.00, 10.00, '单支', '纯洁百合，馨香怡人', 60, 15, 1),
(1, '康乃馨', 'F005', 8.80, 4.50, '单支', '感恩康乃馨，母亲节首选', 120, 25, 1),
(1, '满天星', 'F006', 7.50, 3.80, '束', '浪漫满天星，花束必备', 150, 30, 1),
(1, '混合花束', 'F007', 128.00, 65.00, '中型', '精美混合花束，节日送礼佳品', 30, 5, 1),

-- 绿植类
(2, '绿萝', 'P001', 35.00, 18.00, '小型盆栽', '室内净化空气绿植，好养易活', 40, 8, 1),
(2, '发财树', 'P002', 189.00, 98.00, '中型盆栽', '招财进宝，公司开业首选', 15, 3, 1),
(2, '多肉植物', 'P003', 25.00, 12.50, '小型盆栽', '可爱多肉，桌面装饰', 70, 15, 1),
(2, '富贵竹', 'P004', 45.00, 23.00, '水培', '寓意富贵平安，水培易养', 35, 7, 1),

-- 花篮类
(3, '开业花篮', 'B001', 388.00, 198.00, '大型', '开业庆典花篮，红色主题', 10, 2, 1),
(3, '祝贺花篮', 'B002', 268.00, 138.00, '中型', '商务祝贺花篮，黄色主题', 15, 3, 1),
(3, '葬礼花圈', 'B003', 298.00, 158.00, '标准', '传统白色花圈，表达哀思', 8, 2, 1),

-- 礼品类
(4, '小熊公仔', 'G001', 45.00, 22.00, '25cm', '可爱毛绒小熊，花束搭配', 60, 10, 1),
(4, '巧克力礼盒', 'G002', 68.00, 35.00, '12颗装', '高档巧克力礼盒，花束搭配', 40, 8, 1),
(4, '精美花瓶', 'G003', 88.00, 45.00, '中号', '高档陶瓷花瓶，插花必备', 25, 5, 1),
(4, '贺卡', 'G004', 5.00, 1.50, '标准', '精美贺卡，赠送祝福', 200, 50, 1);

-- 插入库存变动记录
INSERT INTO `inventory_records` (`product_id`, `type`, `quantity`, `before_stock`, `after_stock`, `price`, `supplier_id`, `remark`, `operator`) VALUES
-- 初始入库记录
(1, 1, 100, 0, 100, 5.50, 1, '初始库存入库', 'admin'),
(2, 1, 50, 0, 50, 8.50, 1, '初始库存入库', 'admin'),
(3, 1, 80, 0, 80, 7.00, 1, '初始库存入库', 'admin'),
(4, 1, 60, 0, 60, 10.00, 1, '初始库存入库', 'admin'),
(5, 1, 120, 0, 120, 4.50, 1, '初始库存入库', 'admin'),
(6, 1, 150, 0, 150, 3.80, 1, '初始库存入库', 'admin'),
(7, 1, 30, 0, 30, 65.00, 1, '初始库存入库', 'admin'),
(8, 1, 40, 0, 40, 18.00, 2, '初始库存入库', 'admin'),
(9, 1, 15, 0, 15, 98.00, 2, '初始库存入库', 'admin'),
(10, 1, 70, 0, 70, 12.50, 2, '初始库存入库', 'admin'),
(11, 1, 35, 0, 35, 23.00, 2, '初始库存入库', 'admin'),
(12, 1, 10, 0, 10, 198.00, 3, '初始库存入库', 'admin'),
(13, 1, 15, 0, 15, 138.00, 3, '初始库存入库', 'admin'),
(14, 1, 8, 0, 8, 158.00, 3, '初始库存入库', 'admin'),
(15, 1, 60, 0, 60, 22.00, 4, '初始库存入库', 'admin'),
(16, 1, 40, 0, 40, 35.00, 4, '初始库存入库', 'admin'),
(17, 1, 25, 0, 25, 45.00, 4, '初始库存入库', 'admin'),
(18, 1, 200, 0, 200, 1.50, 4, '初始库存入库', 'admin'),

-- 销售出库记录
(1, 2, -5, 100, 95, 9.90, NULL, '销售出库', '店员A'),
(2, 2, -3, 50, 47, 15.80, NULL, '销售出库', '店员A'),
(3, 2, -2, 80, 78, 12.50, NULL, '销售出库', '店员B'),
(7, 2, -2, 30, 28, 128.00, NULL, '销售出库', '店员A'),
(8, 2, -1, 40, 39, 35.00, NULL, '销售出库', '店员B'),
(12, 2, -1, 10, 9, 388.00, NULL, '公司开业订单', '店员C'),

-- 报损记录
(1, 3, -2, 95, 93, NULL, NULL, '花朵枯萎', '店员A'),
(4, 3, -1, 60, 59, NULL, NULL, '运输损坏', '店员B'),
(10, 3, -3, 70, 67, NULL, NULL, '保存不当干枯', '店员C'),

-- 盘点调整记录
(5, 4, 5, 120, 125, NULL, NULL, '盘点发现实际多于系统', '店长'),
(6, 4, -2, 150, 148, NULL, NULL, '盘点发现实际少于系统', '店长'),
(16, 4, -1, 40, 39, NULL, NULL, '盘点调整', '店长'),

-- 额外采购记录
(1, 1, 30, 93, 123, 5.30, 1, '补充库存', '店长'),
(7, 1, 10, 28, 38, 63.00, 1, '热销商品补货', '店长'),
(9, 1, 5, 15, 20, 95.00, 2, '补充高价值商品', '店长'),
(12, 1, 3, 9, 12, 190.00, 3, '开业季节补货', '店长');

-- 订单主表
CREATE TABLE IF NOT EXISTS `orders` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '订单ID',
    `order_no` varchar(20) NOT NULL COMMENT '订单编号',
    `member_id` int(11) DEFAULT NULL COMMENT '会员ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `total_amount` decimal(10, 2) NOT NULL COMMENT '订单总金额',
    `discount_amount` decimal(10, 2) DEFAULT 0.00 COMMENT '折扣金额',
    `actual_amount` decimal(10, 2) NOT NULL COMMENT '实际支付金额',
    `points_used` int(11) DEFAULT 0 COMMENT '使用的积分数量',
    `points_discount` decimal(10, 2) DEFAULT 0.00 COMMENT '积分抵扣金额',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '订单状态(1:待付款,2:已付款,3:待配送,4:已完成,5:已取消,6:退款中,7:已退款)',
    `remark` varchar(255) DEFAULT NULL COMMENT '订单备注',
    `operator` varchar(50) DEFAULT NULL COMMENT '操作员',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_order_no` (`order_no`),
    KEY `idx_member` (`member_id`),
    KEY `idx_store` (`store_id`),
    KEY `idx_status` (`status`),
    CONSTRAINT `fk_order_member` FOREIGN KEY (`member_id`) REFERENCES `members` (`id`) ON DELETE SET NULL,
    CONSTRAINT `fk_order_store` FOREIGN KEY (`store_id`) REFERENCES `stores` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '订单主表';

-- 订单商品表
CREATE TABLE IF NOT EXISTS `order_items` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '订单商品ID',
    `order_id` int(11) NOT NULL COMMENT '订单ID',
    `product_id` int(11) NOT NULL COMMENT '商品ID',
    `product_name` varchar(100) NOT NULL COMMENT '商品名称',
    `product_code` varchar(50) NOT NULL COMMENT '商品编码',
    `price` decimal(10, 2) NOT NULL COMMENT '商品单价',
    `quantity` int(11) NOT NULL COMMENT '商品数量',
    `subtotal` decimal(10, 2) NOT NULL COMMENT '小计金额',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_order` (`order_id`),
    KEY `idx_product` (`product_id`),
    CONSTRAINT `fk_item_order` FOREIGN KEY (`order_id`) REFERENCES `orders` (`id`) ON DELETE CASCADE,
    CONSTRAINT `fk_item_product` FOREIGN KEY (`product_id`) REFERENCES `products` (`id`) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '订单商品表';

-- 订单支付表
CREATE TABLE IF NOT EXISTS `order_payments` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '支付ID',
    `order_id` int(11) NOT NULL COMMENT '订单ID',
    `payment_type` tinyint(1) NOT NULL COMMENT '支付方式(1:现金,2:微信,3:支付宝,4:信用卡,5:储值余额,6:积分抵扣)',
    `amount` decimal(10, 2) NOT NULL COMMENT '支付金额',
    `transaction_id` varchar(64) DEFAULT NULL COMMENT '交易流水号',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '支付状态(1:待支付,2:支付成功,3:支付失败)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    KEY `idx_order` (`order_id`),
    CONSTRAINT `fk_payment_order` FOREIGN KEY (`order_id`) REFERENCES `orders` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '订单支付表';

-- 订单退款表
CREATE TABLE IF NOT EXISTS `order_refunds` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '退款ID',
    `order_id` int(11) NOT NULL COMMENT '订单ID',
    `refund_no` varchar(20) NOT NULL COMMENT '退款编号',
    `refund_amount` decimal(10, 2) NOT NULL COMMENT '退款金额',
    `reason` varchar(255) NOT NULL COMMENT '退款原因',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '退款状态(1:申请中,2:已审核,3:退款成功,4:退款失败)',
    `apply_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '申请时间',
    `audit_user` varchar(50) DEFAULT NULL COMMENT '审核人',
    `audit_time` datetime DEFAULT NULL COMMENT '审核时间',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_refund_no` (`refund_no`),
    KEY `idx_order` (`order_id`),
    CONSTRAINT `fk_refund_order` FOREIGN KEY (`order_id`) REFERENCES `orders` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '订单退款表';

-- 插入示例订单数据
INSERT INTO `orders` (`order_no`, `member_id`, `store_id`, `total_amount`, `discount_amount`, `actual_amount`, `points_used`, `points_discount`, `status`, `remark`, `operator`) VALUES
-- 普通订单（非会员）
('ORD20230501001', NULL, 1, 99.00, 0.00, 99.00, 0, 0.00, 4, '店内购买', '店员A'),
-- 会员订单（假设member_id=1存在）
('ORD20230501002', 1, 1, 256.00, 25.60, 230.40, 0, 0.00, 4, '会员9折优惠', '店员A'),
-- 会员订单+积分抵扣
('ORD20230502001', 1, 1, 188.00, 18.80, 159.20, 100, 10.00, 4, '会员9折+100积分抵扣10元', '店员B'),
-- 待付款订单
('ORD20230503001', NULL, 1, 135.50, 0.00, 135.50, 0, 0.00, 1, '预订单', '店员C'),
-- 已付款待配送
('ORD20230503002', 1, 1, 288.00, 28.80, 259.20, 0, 0.00, 3, '需配送', '店员A'),
-- 已取消订单
('ORD20230504001', NULL, 1, 75.00, 0.00, 75.00, 0, 0.00, 5, '客户取消', '店员B'),
-- 退款中订单
('ORD20230504002', 1, 1, 192.00, 19.20, 172.80, 0, 0.00, 6, '客户申请退款', '店员C'),
-- 已退款订单
('ORD20230505001', 1, 1, 145.00, 14.50, 130.50, 0, 0.00, 7, '已办理退款', '店员A');

-- 插入订单商品明细
INSERT INTO `order_items` (`order_id`, `product_id`, `product_name`, `product_code`, `price`, `quantity`, `subtotal`) VALUES
-- 订单1的商品
(1, 1, '红玫瑰', 'F001', 9.90, 10, 99.00),
-- 订单2的商品
(2, 7, '混合花束', 'F007', 128.00, 2, 256.00),
-- 订单3的商品
(3, 4, '百合花', 'F004', 18.00, 5, 90.00),
(3, 5, '康乃馨', 'F005', 8.80, 8, 70.40),
(3, 6, '满天星', 'F006', 7.50, 2, 15.00),
(3, 18, '贺卡', 'G004', 5.00, 1, 5.00),
-- 订单4的商品
(4, 15, '小熊公仔', 'G001', 45.00, 1, 45.00),
(4, 16, '巧克力礼盒', 'G002', 68.00, 1, 68.00),
(4, 18, '贺卡', 'G004', 5.00, 1, 5.00),
-- 订单5的商品
(5, 12, '开业花篮', 'B001', 388.00, 1, 388.00),
-- 订单6的商品
(6, 2, '向日葵', 'F002', 15.80, 3, 47.40),
(6, 3, '郁金香', 'F003', 12.50, 1, 12.50),
(6, 18, '贺卡', 'G004', 5.00, 3, 15.00),
-- 订单7的商品
(7, 7, '混合花束', 'F007', 128.00, 1, 128.00),
(7, 16, '巧克力礼盒', 'G002', 68.00, 1, 68.00),
-- 订单8的商品
(8, 13, '祝贺花篮', 'B002', 268.00, 1, 268.00);

-- 插入支付记录
INSERT INTO `order_payments` (`order_id`, `payment_type`, `amount`, `transaction_id`, `status`) VALUES
-- 已完成订单的支付记录
(1, 1, 99.00, 'CASH20230501001', 2), -- 现金支付
(2, 3, 230.40, 'ALIPAY20230501002', 2), -- 支付宝支付
(3, 5, 159.20, 'BALANCE20230502001', 2), -- 储值余额支付
(5, 2, 259.20, 'WXPAY20230503002', 2), -- 微信支付
(7, 2, 172.80, 'WXPAY20230504002', 2), -- 微信支付(后来申请退款)
(8, 4, 130.50, 'CARD20230505001', 2); -- 信用卡支付(已退款)

-- 插入退款记录
INSERT INTO `order_refunds` (`order_id`, `refund_no`, `refund_amount`, `reason`, `status`, `audit_user`, `audit_time`) VALUES
-- 退款中订单
(7, 'REF20230504001', 172.80, '商品质量问题', 1, NULL, NULL),
-- 已退款订单
(8, 'REF20230505001', 130.50, '客户不喜欢', 3, '店长', '2023-05-05 15:30:00');

-- 配送管理相关表
-- 配送员信息表
CREATE TABLE IF NOT EXISTS `delivery_staff` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '配送员ID',
    `name` varchar(50) NOT NULL COMMENT '姓名',
    `phone` varchar(20) NOT NULL COMMENT '联系电话',
    `area` varchar(100) NOT NULL COMMENT '负责区域',
    `vehicle_type` varchar(20) NOT NULL COMMENT '交通工具类型',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(0:离职,1:在职,2:休假)',
    `avg_rating` decimal(3, 2) DEFAULT 5.00 COMMENT '平均评分',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `uk_phone` (`phone`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '配送员信息表';

-- 配送员排班表
CREATE TABLE IF NOT EXISTS `delivery_schedules` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '排班ID',
    `staff_id` int(11) NOT NULL COMMENT '配送员ID',
    `date` date NOT NULL COMMENT '排班日期',
    `start_time` time NOT NULL COMMENT '开始时间',
    `end_time` time NOT NULL COMMENT '结束时间',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态(0:取消,1:正常)',
    PRIMARY KEY (`id`),
    KEY `idx_staff_date` (`staff_id`, `date`),
    CONSTRAINT `fk_schedule_staff` FOREIGN KEY (`staff_id`) REFERENCES `delivery_staff` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '配送员排班表';

-- 配送任务表
CREATE TABLE IF NOT EXISTS `delivery_tasks` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '任务ID',
    `order_id` int(11) NOT NULL COMMENT '订单ID',
    `staff_id` int(11) DEFAULT NULL COMMENT '配送员ID',
    `delivery_type` tinyint(1) NOT NULL DEFAULT 1 COMMENT '配送类型(1:即时配送,2:预约配送)',
    `expected_time` datetime DEFAULT NULL COMMENT '预计送达时间',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态(1:待分配,2:配送中,3:已送达,4:已确认,5:配送失败)',
    `route_info` varchar(255) DEFAULT NULL COMMENT '路线信息',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注信息',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `uk_order_id` (`order_id`),
    KEY `idx_staff_id` (`staff_id`),
    CONSTRAINT `fk_delivery_order` FOREIGN KEY (`order_id`) REFERENCES `orders` (`id`) ON DELETE CASCADE,
    CONSTRAINT `fk_delivery_staff` FOREIGN KEY (`staff_id`) REFERENCES `delivery_staff` (`id`) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '配送任务表';

-- 配送评价表
CREATE TABLE IF NOT EXISTS `delivery_ratings` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '评价ID',
    `task_id` int(11) NOT NULL COMMENT '配送任务ID',
    `staff_id` int(11) NOT NULL COMMENT '配送员ID',
    `rating` int(11) NOT NULL DEFAULT 5 COMMENT '评分(1-5)',
    `comment` varchar(500) DEFAULT NULL COMMENT '评价内容',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '评价时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `uk_task_id` (`task_id`),
    CONSTRAINT `fk_rating_task` FOREIGN KEY (`task_id`) REFERENCES `delivery_tasks` (`id`) ON DELETE CASCADE,
    CONSTRAINT `fk_rating_staff` FOREIGN KEY (`staff_id`) REFERENCES `delivery_staff` (`id`) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '配送评价表';

-- 插入配送员数据
INSERT INTO `delivery_staff` (`name`, `phone`, `area`, `vehicle_type`, `status`, `avg_rating`) VALUES
('张三', '13800138001', '朝阳区北部', '电动车', 1, 4.80),
('李四', '13800138002', '海淀区西部', '电动车', 1, 4.75),
('王五', '13800138003', '西城区,东城区', '电动三轮', 2, 4.90);

-- 插入排班数据
INSERT INTO `delivery_schedules` (`staff_id`, `date`, `start_time`, `end_time`, `status`) VALUES
(1, '2023-05-01', '08:00:00', '18:00:00', 1),
(2, '2023-05-01', '08:00:00', '18:00:00', 1),
(3, '2023-05-01', '08:00:00', '18:00:00', 0), -- 休假
(1, '2023-05-02', '08:00:00', '18:00:00', 1),
(2, '2023-05-02', '08:00:00', '18:00:00', 1);

-- 插入配送任务数据
INSERT INTO `delivery_tasks` (`order_id`, `staff_id`, `delivery_type`, `expected_time`, `status`, `route_info`, `remark`) VALUES
(1, 1, 1, '2023-05-01 15:30:00', 4, '朝阳区建国路88号', '顺利送达并确认'), 
(2, 2, 1, '2023-05-01 16:45:00', 4, '海淀区中关村大街1号', '正常送达'),
(5, 2, 2, '2023-05-02 14:00:00', 2, '东城区东长安街9号', '正在配送中');

-- 插入配送评价数据
INSERT INTO `delivery_ratings` (`task_id`, `staff_id`, `rating`, `comment`) VALUES
(1, 1, 5, '配送员很专业，鲜花包装完好'),
(2, 2, 4, '准时送达，但包装略有破损');

-- 财务管理相关表
-- 财务记录表
CREATE TABLE `finance_records` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `type` tinyint(1) NOT NULL COMMENT '类型(1:收入,2:支出,3:供应商结算)',
    `category` varchar(50) NOT NULL COMMENT '类别(订单收入/会员充值/采购成本/工资/结算等)',
    `amount` decimal(10, 2) NOT NULL COMMENT '金额',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `related_id` int(11) DEFAULT NULL COMMENT '关联ID(订单ID/供应商ID等)',
    `period` varchar(20) DEFAULT NULL COMMENT '结算周期(如:2023-05)',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态(1:未结算,2:已结算)',
    `description` varchar(255) DEFAULT NULL COMMENT '描述',
    `record_date` date NOT NULL COMMENT '记录日期',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_type_date` (`type`, `record_date`),
    KEY `idx_related` (`related_id`),
    KEY `idx_store` (`store_id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '财务记录表';

-- 收入记录
INSERT INTO `finance_records` (`type`, `category`, `amount`, `store_id`, `related_id`, `period`, `status`, `description`, `record_date`) VALUES
(1, '订单收入', 256.00, 1, 2, NULL, NULL, '订单ORD20230501002收入', '2023-05-01'),
(1, '订单收入', 188.00, 1, 3, NULL, NULL, '订单ORD20230502001收入', '2023-05-02'),
(1, '会员充值', 300.00, 1, 1, NULL, NULL, '会员张三充值收入', '2023-05-03'),
(1, '订单收入', 268.00, 1, 8, NULL, NULL, '订单ORD20230505001收入', '2023-05-05');

-- 支出记录
INSERT INTO `finance_records` (`type`, `category`, `amount`, `store_id`, `related_id`, `period`, `status`, `description`, `record_date`) VALUES
(2, '员工工资', 5000.00, 1, NULL, '2023-05', NULL, '5月份员工工资支出', '2023-05-10'),
(2, '房租', 3500.00, 1, NULL, '2023-05', NULL, '5月份门店租金', '2023-05-15'),
(2, '水电费', 800.00, 1, NULL, '2023-05', NULL, '5月份水电费', '2023-05-20'),
(2, '采购成本', 3000.00, 1, NULL, '2023-05', NULL, '5月份花卉采购', '2023-05-25');

-- 供应商结算记录
INSERT INTO `finance_records` (`type`, `category`, `amount`, `store_id`, `related_id`, `period`, `status`, `description`, `record_date`) VALUES
(3, '供应商结算', 3000.00, 1, 1, '2023-05', 2, '5月份北京花卉批发市场结算', '2023-05-31'),
(3, '供应商结算', 1500.00, 1, 2, '2023-05', 1, '5月份绿色园艺有限公司结算', '2023-05-31');

-- 营销推广相关表
-- 营销活动表（优惠券和促销活动统一管理）
CREATE TABLE IF NOT EXISTS `marketing_campaigns` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `name` varchar(100) NOT NULL COMMENT '活动名称',
    `type` tinyint(1) NOT NULL COMMENT '活动类型：1满减券，2折扣券，3限时优惠，4套餐促销，5充值送礼，6节日促销，7推荐返利',
    `description` varchar(255) DEFAULT NULL COMMENT '活动描述',
    `discount_type` tinyint(1) NOT NULL COMMENT '优惠类型：1固定金额，2百分比',
    `discount_value` decimal(10, 2) NOT NULL COMMENT '优惠值',
    `min_amount` decimal(10, 2) DEFAULT 0 COMMENT '最低消费金额',
    `start_time` datetime NOT NULL COMMENT '开始时间',
    `end_time` datetime NOT NULL COMMENT '结束时间',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：0禁用，1启用',
    `usage_limit` int(11) DEFAULT NULL COMMENT '每人使用次数限制',
    `target_level_id` int(11) DEFAULT NULL COMMENT '目标会员等级，NULL表示所有等级',
    `create_time` datetime DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '营销活动表';

-- 营销活动商品关联表
CREATE TABLE IF NOT EXISTS `marketing_campaign_products` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `campaign_id` int(11) NOT NULL COMMENT '营销活动ID',
    `product_id` int(11) NOT NULL COMMENT '商品ID',
    `discount_price` decimal(10, 2) DEFAULT NULL COMMENT '促销价格',
    `is_gift` tinyint(1) DEFAULT 0 COMMENT '是否为赠品',
    PRIMARY KEY (`id`),
    KEY `idx_campaign_id` (`campaign_id`),
    KEY `idx_product_id` (`product_id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '营销活动商品关联表';

-- 会员优惠券表
CREATE TABLE IF NOT EXISTS `member_coupons` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `member_id` int(11) NOT NULL COMMENT '会员ID',
    `campaign_id` int(11) NOT NULL COMMENT '优惠券活动ID',
    `code` varchar(20) DEFAULT NULL COMMENT '优惠券码',
    `is_used` tinyint(1) DEFAULT 0 COMMENT '是否已使用',
    `used_time` datetime DEFAULT NULL COMMENT '使用时间',
    `order_id` int(11) DEFAULT NULL COMMENT '关联订单ID',
    `create_time` datetime DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    KEY `idx_member_id` (`member_id`),
    KEY `idx_campaign_id` (`campaign_id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '会员优惠券表';

-- 营销消息模板表
CREATE TABLE IF NOT EXISTS `marketing_templates` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `name` varchar(100) NOT NULL COMMENT '模板名称',
    `type` tinyint(1) NOT NULL COMMENT '模板类型：1短信，2邮件',
    `subject` varchar(200) DEFAULT NULL COMMENT '邮件主题',
    `content` text NOT NULL COMMENT '内容，使用{变量名}格式的占位符',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：0禁用，1启用',
    `create_time` datetime DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '营销消息模板表';

-- 优惠券活动初始数据
INSERT INTO `marketing_campaigns` 
(`name`, `type`, `description`, `discount_type`, `discount_value`, `min_amount`, `start_time`, `end_time`, `status`, `usage_limit`, `target_level_id`) 
VALUES 
('新会员满100减20', 1, '新会员专享优惠券，满100元减20元', 1, 20.00, 100.00, '2023-01-01 00:00:00', '2023-12-31 23:59:59', 1, 1, NULL),
('VIP会员8折优惠', 2, 'VIP会员专享折扣券，消费享8折优惠', 2, 0.80, 0.00, '2023-01-01 00:00:00', '2023-12-31 23:59:59', 1, 5, 2),
('情人节特惠活动', 3, '情人节期间，玫瑰花束特惠', 2, 0.85, 0.00, '2023-02-01 00:00:00', '2023-02-14 23:59:59', 1, NULL, NULL),
('充值送礼活动', 5, '充值满300元送50元', 1, 50.00, 300.00, '2023-01-01 00:00:00', '2023-12-31 23:59:59', 1, NULL, NULL),
('生日送礼活动', 6, '会员生日当月获赠优惠券', 1, 30.00, 0.00, '2023-01-01 00:00:00', '2023-12-31 23:59:59', 1, NULL, NULL),
('好友推荐奖励', 7, '推荐新会员注册，双方各获得50积分', 1, 50.00, 0.00, '2023-01-01 00:00:00', '2023-12-31 23:59:59', 1, NULL, NULL);

-- 营销活动商品关联初始数据
INSERT INTO `marketing_campaign_products` 
(`campaign_id`, `product_id`, `discount_price`, `is_gift`) 
VALUES 
(3, 1, 85.00, 0),  -- 情人节活动关联玫瑰花产品
(3, 5, 68.00, 0);  -- 情人节活动关联其他产品

-- 营销消息模板初始数据
INSERT INTO `marketing_templates` 
(`name`, `type`, `subject`, `content`, `status`) 
VALUES 
('生日祝福短信', 1, NULL, '亲爱的{name}，祝您生日快乐！作为生日礼物，我们已向您的账户发送了一张30元优惠券，有效期30天。祝您购物愉快！', 1),
('订单确认邮件', 2, '您的订单已确认', '尊敬的{name}，您的订单{order_no}已确认，预计将于{delivery_time}送达，感谢您的惠顾！', 1),
('节日促销短信', 1, NULL, '亲爱的{name}，{holiday}快乐！{store_name}推出{discount}折特惠活动，活动时间：{start_date}至{end_date}，欢迎选购！', 1);

-- 会员优惠券初始数据
INSERT INTO `member_coupons` 
(`member_id`, `campaign_id`, `code`, `is_used`, `create_time`) 
VALUES 
(1, 1, 'NEW100OFF20', 0, '2023-01-05 10:00:00'),
(2, 2, 'VIP80OFF', 0, '2023-01-05 10:00:00'),
(3, 5, 'BIRTH30OFF', 1, '2023-01-05 10:00:00');

-- 数据统计表
CREATE TABLE IF NOT EXISTS `data_statistics` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `statistic_type` varchar(30) NOT NULL COMMENT '统计类型(sales,product,member,order,inventory)',
    `reference_id` int(11) DEFAULT NULL COMMENT '关联ID(商品ID/会员ID/门店ID等)',
    `period_type` varchar(10) NOT NULL COMMENT '周期类型(day,week,month,year)',
    `period_value` varchar(20) NOT NULL COMMENT '周期值(20230601)',
    `numeric_value1` decimal(12,2) DEFAULT 0 COMMENT '数值1(销售额/数量等)',
    `numeric_value2` decimal(12,2) DEFAULT 0 COMMENT '数值2(利润/成本等)',
    `numeric_value3` decimal(12,2) DEFAULT 0 COMMENT '数值3(订单数/会员数等)',
    `text_value` varchar(255) DEFAULT NULL COMMENT '文本值(描述/类型等)',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_type_ref_period` (`statistic_type`, `reference_id`, `period_type`, `period_value`),
    KEY `idx_period` (`period_type`, `period_value`),
    KEY `idx_type` (`statistic_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='数据统计表';

