<?php
// statistics/index.php - 数据统计与分析首页
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('statistics.view');

// 记录访问日志
record_log('访问数据统计与分析首页');

// 获取数据统计概况
try {
    // 销售统计数据
    $sales_stats = [
        'days' => 0,
        'latest_date' => '无数据'
    ];

    $stmt = $pdo->query("
        SELECT 
            COUNT(DISTINCT period_value) as days,
            MAX(STR_TO_DATE(period_value, '%Y%m%d')) as latest_date
        FROM data_statistics
        WHERE statistic_type = 'sales'
        AND period_type = 'day'
    ");
    if ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $sales_stats['days'] = $row['days'];
        $sales_stats['latest_date'] = $row['latest_date'] ?: '无数据';
    }

    // 热销商品统计
    $hot_products_count = 0;
    $stmt = $pdo->query("
        SELECT COUNT(DISTINCT reference_id) as count
        FROM data_statistics
        WHERE statistic_type = 'product'
    ");
    if ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $hot_products_count = $row['count'];
    }

    // 会员统计数据
    $member_count = 0;
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM members");
    if ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $member_count = $row['count'];
    }

    // 订单统计数据
    $order_stats = [
        'total' => 0,
        'today' => 0
    ];

    $stmt = $pdo->query("SELECT COUNT(*) as count FROM orders");
    if ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $order_stats['total'] = $row['count'];
    }

    $stmt = $pdo->query("SELECT COUNT(*) as count FROM orders WHERE DATE(create_time) = CURDATE()");
    if ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $order_stats['today'] = $row['count'];
    }

    // 库存统计数据
    $inventory_count = 0;
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM inventory_records");
    if ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $inventory_count = $row['count'];
    }
} catch (PDOException $e) {
    $error_message = '获取统计概况失败: ' . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>数据统计与分析 - FloraEase花店管理系统</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>数据统计与分析</h2>
        </div>

        <div class="content">
            <?php if (!empty($error_message)): ?>
                <div class="alert alert-danger">
                    <?php echo $error_message; ?>
                </div>
            <?php endif; ?>

            <!-- 数据概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>销售统计</h3>
                    <div class="number"><?php echo $sales_stats['days']; ?></div>
                    <div class="desc">已统计天数</div>
                </div>
                <div class="dashboard-card">
                    <h3>热销商品</h3>
                    <div class="number"><?php echo $hot_products_count; ?></div>
                    <div class="desc">已统计商品数</div>
                </div>
                <div class="dashboard-card">
                    <h3>会员总数</h3>
                    <div class="number"><?php echo $member_count; ?></div>
                    <div class="desc">活跃会员比例 68%</div>
                </div>
                <div class="dashboard-card">
                    <h3>今日订单</h3>
                    <div class="number"><?php echo $order_stats['today']; ?></div>
                    <div class="desc">订单总数: <?php echo $order_stats['total']; ?></div>
                </div>
            </div>

            <!-- 功能导航 -->
            <h2>统计功能</h2>
            <div class="function-links">
                <a href="sales.php" class="function-link">
                    <h3>销售统计</h3>
                </a>
                <a href="member.php" class="function-link">
                    <h3>会员数据</h3>
                </a>
                <a href="order.php" class="function-link">
                    <h3>订单数据</h3>
                </a>
                <a href="inventory.php" class="function-link">
                    <h3>库存数据</h3>
                </a>
            </div>

            <!-- 数据统计状态 -->
            <h2>数据统计状态</h2>
            <div class="system-info">
                <table class="info-table">
                    <tr>
                        <td width="25%">销售数据最新统计日期：</td>
                        <td><?php echo $sales_stats['latest_date']; ?></td>
                    </tr>
                    <tr>
                        <td>热销商品统计范围：</td>
                        <td>最近60天内</td>
                    </tr>
                    <tr>
                        <td>会员活跃度统计标准：</td>
                        <td>30天内有消费记录为活跃会员</td>
                    </tr>
                    <tr>
                        <td>订单统计期间：</td>
                        <td>全部历史订单</td>
                    </tr>
                    <tr>
                        <td>库存周转率计算周期：</td>
                        <td>最近90天</td>
                    </tr>
                </table>
            </div>
        </div>
    </div>
</body>

</html>